package com.jty.wsxt.interfaces.controller;

import com.jty.wsxt.application.ApplicationRegistry;
import com.jty.wsxt.application.feign.UserFeign;
import com.jty.wsxt.domain.model.paper.Paper;
import com.jty.wsxt.infrastructure.support.Result;
import com.jty.wsxt.interfaces.dto.PaperDto;
import com.jty.wsxt.interfaces.dto.PaperSearchDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * PaperController
 *
 * @author Manjiajie
 * @since 2019-6-21 13:42:12
 */
@RestController
public class PaperController {

    private final UserFeign userFeign;

    @Autowired
    public PaperController(UserFeign userFeign) {
        this.userFeign = userFeign;
    }

    @PostMapping
    public Result addPaper(@RequestBody PaperSearchDto paperSearchDto){
        paperSearchDto.setCreatorId(userFeign.getLoginId());
        paperSearchDto.setCreatorName(userFeign.getLoginName());
        ApplicationRegistry.paperService().addPaper(paperSearchDto);
        return Result.success();
    }

    @GetMapping("/papers")
    public Result getPapers(PaperSearchDto paperSearchDto){
        Page<Paper> paperPage = ApplicationRegistry.paperService().findPagePaper(paperSearchDto);
        List<PaperDto> paperDtos = new ArrayList<>();
        if(paperPage.getTotalElements() != 0){
            paperPage.getContent().forEach(paper -> paperDtos.add(paper.cashToPaperDto()));
        }
        return Result.success(new PageImpl<>(paperDtos,paperPage.getPageable(),paperPage.getTotalElements()));
    }
}
